@@ -24,7 +24,7 @@
 #ifndef GTK_INTERNET_RADIO_LOCATOR_KEYS_H
 #define GTK_INTERNET_RADIO_LOCATOR_KEYS_H
 
-#define GTK_INTERNET_RADIO_LOCATOR_DOMAIN "org.gnomeradio.gtk-internet-radio-locator"
+#define GTK_INTERNET_RADIO_LOCATOR_DOMAIN "org.gtk.gtk-internet-radio-locator"
 #define GTK_INTERNET_RADIO_LOCATOR_UI GTK_INTERNET_RADIO_LOCATOR_DOMAIN".ui"
 #define GTK_INTERNET_RADIO_LOCATOR_STATION "station"
 
