@@ -1,10 +1,10 @@
 /* $Id$
  *
- * GTK Internet Radio Locator for GTK 4
+ * GTK Internet Radio Locator for GTK
  *
- * Copyright (C) 2014, 2015, 2016, 2017, 2018, 2022, 2025, 2026  Aamot Research
+ * Copyright (C) 2014, 2015, 2016, 2017, 2018, 2022, 2023  Aamot Software
  *
- * Author: Ole Aamot <ole@aamot.org>
+ * Author: Ole Aamot <ole@gnome.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -534,7 +534,7 @@ gtk_internet_radio_locator_window_cb (GtkApplication *app,
 	widget = gtk_champlain_embed_new();
 	toolbar = gtk_toolbar_new();
 	input = gtk_entry_new();
-
+	gtk_entry_set_placeholder_text(GTK_ENTRY(input), "Search by city...");
 #if 0
 	search = gtk_tool_button_new(gtk_image_new_from_icon_name(NULL, GTK_ICON_SIZE_BUTTON), _("Search"));
 	gtk_tool_item_set_is_important(GTK_TOOL_ITEM(search), TRUE);
@@ -589,7 +589,7 @@ gtk_internet_radio_locator_window_cb (GtkApplication *app,
 	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(grid));
 	g_signal_connect (window, "destroy", G_CALLBACK(gtk_main_quit), NULL);
 #endif
-	gtk_window_set_title (GTK_WINDOW(window), _("Internet Radio Locator for GTK 4"));
+	gtk_window_set_title (GTK_WINDOW(window), _("Internet Radio Locator for GTK"));
 	gtk_window_set_default_size (GTK_WINDOW(window), 1440, 720);
 
 	gtk_internet_radio_locator_app = create_gtk_internet_radio_locator_app();
@@ -759,7 +759,7 @@ main (int argc,
 	/* give the window a 10px wide border */
 	gtk_container_set_border_width (GTK_CONTAINER (window), 10);
 	/* give it the title */
-	gtk_window_set_title (GTK_WINDOW (window), _("Internet Radio Locator for GTK 4"));
+	gtk_window_set_title (GTK_WINDOW (window), _("Internet Radio Locator for GTK"));
 	/* Connect the destroy event of the window with our on_destroy function
 	 * When the window is about to be destroyed we get a notificaiton and
 	 * stop the main GTK loop
@@ -794,8 +794,8 @@ main (int argc,
 	clutter_actor_add_child (CLUTTER_ACTOR (view), scale);
 
 	license_actor = champlain_view_get_license_actor (view);
-	champlain_license_set_extra_text (license_actor, "Internet Talk Radio");
-	champlain_view_center_on (CHAMPLAIN_VIEW (view), 44.949252, -93.0978326);
+	champlain_license_set_extra_text (license_actor, "Free Internet Radio");
+	champlain_view_center_on (CHAMPLAIN_VIEW (view), 48.8582602, 2.29449905431968);
 	layer = create_marker_layer (view, &path);
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (path));
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (layer));
@@ -813,7 +813,7 @@ main (int argc,
 	append_point (path_layer, 45.4151, -73.1218);
 	champlain_view_add_layer (view, CHAMPLAIN_LAYER (path_layer));
 
-	gtk_widget_set_size_request (widget, 640, 480);
+	gtk_widget_set_size_request (widget, 640, 481);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
 
@@ -841,6 +841,7 @@ main (int argc,
 	gtk_entry_completion_set_text_column(completion, STATION_NAME);
 	gtk_entry_completion_set_text_column(completion, STATION_LOCATION);
 	gtk_entry_set_completion(GTK_ENTRY(input), completion);
+	gtk_entry_set_placeholder_text(GTK_ENTRY(input), "Search by city...");
 	g_signal_connect(G_OBJECT(completion), "match-selected",
 			 G_CALLBACK(on_search_matches), NULL);
 	model = gtk_list_store_new(11, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
@@ -993,17 +994,13 @@ main (int argc,
 
 	gst_init(&argc, &argv);
 
-	  player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
-	  gtk_internet_radio_locator_player_new(player, "https://playerservices.streamtheworld.com/api/livestream-redirect/CSPANRADIO.mp3");
-  gst_player_play(player);
-
 	/* start the main loop */
 	gtk_main ();
 
 	return 0;
 #if 0
 	
-	app = gtk_application_new ("org.gnomeradio.gtk-internet-radio-locator", G_APPLICATION_FLAGS_NONE);
+	app = gtk_application_new ("org.gnome.gtk-internet-radio-locator", G_APPLICATION_FLAGS_NONE);
 
 	g_signal_connect (app, "activate", G_CALLBACK (gtk_internet_radio_locator_window_cb), NULL);
 	
